import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

// Palenight theme color definitions
const base00 = '#292D3E', // Background
base01 = '#A6ACCD', // Foreground
base02 = '#444267', // Darker selection match
base03 = '#676E95', // Comments
base04 = '#A6ACCD', // Cursor color
base05 = '#C3E88D', // Green for strings and regex
base06 = '#33374D', // Line highlight
base07 = '#82AAFF', // Blue for keywords, type names, and operators
base08 = '#F78C6C'; // Orange for numbers, headings, and constants
const invalid = '#FF5370', // Red for invalid elements
darkBackground = base00, highlightBackground = base06, background = base00, // Main background
tooltipBackground = '#444267', selection = '#444267', cursor = base04; // Cursor color
// The editor theme styles for Palenight
const palenightTheme = /*@__PURE__*/EditorView.theme({
    '&': {
        color: base01,
        backgroundColor: background,
    },
    '.cm-content': {
        caretColor: cursor,
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection,
    },
    '.cm-panels': {
        backgroundColor: darkBackground,
        color: base03,
    },
    '.cm-activeLine': {
        backgroundColor: highlightBackground,
    },
    '.cm-selectionMatch': {
        backgroundColor: base02,
    },
    '&.cm-focused .cm-matchingBracket': {
        backgroundColor: highlightBackground,
    },
    '.cm-gutters': {
        backgroundColor: darkBackground,
        color: base03,
        border: 'none',
    },
    '.cm-tooltip': {
        backgroundColor: tooltipBackground,
    },
}, { dark: true });
// The highlighting style for Palenight
const palenightHighlightStyle = /*@__PURE__*/HighlightStyle.define([
    { tag: tags.keyword, color: base07 },
    { tag: [tags.name, tags.deleted, tags.character, tags.macroName], color: base01 },
    { tag: [tags.propertyName], color: base01 },
    {
        tag: [tags.processingInstruction, tags.string, tags.inserted, /*@__PURE__*/tags.special(tags.string)],
        color: base05,
    },
    { tag: [/*@__PURE__*/tags.function(tags.variableName), tags.labelName], color: base01 },
    { tag: [tags.color, /*@__PURE__*/tags.constant(tags.name), /*@__PURE__*/tags.standard(tags.name)], color: base01 },
    { tag: [/*@__PURE__*/tags.definition(tags.name), tags.separator], color: base01 },
    { tag: [tags.className], color: base01 },
    {
        tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace],
        color: base08,
    },
    { tag: [tags.typeName], color: base07 },
    { tag: [tags.operator, tags.operatorKeyword], color: base07 },
    { tag: [tags.url, tags.escape, tags.regexp, tags.link], color: base05 },
    { tag: [tags.meta, tags.comment], color: base03 },
    { tag: tags.tagName, color: base07 },
    { tag: tags.strong, fontWeight: 'bold' },
    { tag: tags.emphasis, fontStyle: 'italic' },
    { tag: tags.link, textDecoration: 'underline' },
    { tag: tags.heading, fontWeight: 'bold', color: base08 },
    { tag: [tags.atom, tags.bool, /*@__PURE__*/tags.special(tags.variableName)], color: base01 },
    { tag: tags.invalid, color: invalid },
    { tag: tags.strikethrough, textDecoration: 'line-through' },
]);
// Extension to enable the Palenight theme (both editor theme and highlight style)
const palenight = [
    palenightTheme,
    /*@__PURE__*/syntaxHighlighting(palenightHighlightStyle),
];

export { palenight, palenightHighlightStyle, palenightTheme };
